##  Introduction
Collecting and maintaining accurate data is crucial for enterprise architecture management. Fact sheet subscription is an effective mechanism for assigning responsibility and accountability to users for maintaining fact sheet data. It ensures that fact sheet subscribers are notified and have a clear call to action to update and maintain the fact sheet data. Fact sheet subscription promotes the active involvement of key stakeholders, drives SAP LeanIX adoption across the organization, and ensures continuous data accuracy and completeness. Subscriptions also make it easy to identify who is responsible for each fact sheet and whom to contact for more information.
Fact sheet subscriptions can be of different types, such as responsible, accountable, and observer, each with a different level of responsibility and involvement of the subscribers. Further, admins can create specific subscription roles that mirror your organization's governance structure and roles, ensuring that relevant individuals can be easily identified and assigned to fact sheets based on their roles.
Users can be assigned to fact sheets, or users can subscribe themselves, selecting the appropriate subscription type and role (if defined). When there are changes in a fact sheet, subscribers receive notifications, enabling them to take necessary actions, such as updating fact sheet info, approving the quality seal, and so on.
